@@ -38,9 +38,30 @@ class Corr(MutiBase):
         self.cov_shrink = None
         self.shrink_list = []
 
-    def fit(self, data, pre_cal=None, method="mean"):
+    @staticmethod
+    def MIC_matirx(dataframe,alpha=0.6, c=15):
+
+        from minepy import MINE
+        mine = MINE(alpha=alpha, c=c)
+        data = np.array(dataframe)
+        n = len(data[0, :])
+        result = np.zeros([n, n])
+
+        for i in range(n):
+            for j in range(n):
+                mine.compute_score(data[:, i], data[:, j])
+                result[i, j] = mine.mic()
+                result[j, i] = mine.mic()
+        RT = result
+        return RT
+
+    def fit(self, data, pre_cal=None, method="mean",alpha=0.6, c=15):
         if pre_cal is None:
-            cov = np.corrcoef(data, rowvar=False)
+
+            cov = np.corrcoef(data, rowvar=False,)
+        elif pre_cal is "mic":
+            cov = self.MIC_matirx(data, alpha=alpha, c=c)
+
         elif isinstance(pre_cal, np.ndarray) and pre_cal.shape[0] == data.shape[1]:
             cov = pre_cal
         else:
@@ -185,3 +206,45 @@ if __name__ == "__main__":
     x, y = load_boston(return_X_y=True)
     co = Corr(threshold=0.7)
     c = co.count_cof(np.corrcoef(x, rowvar=False))[1]
+
+
+    # pandas as pd
+    # import matplotlib.pyplot as plt
+    # import numpy as np
+    #
+
+    #
+    # x = np.linspace(0, 1, 1000)
+    # y = np.sin(10 * np.pi * x) + x
+    # mine = MINE(alpha=0.6, c=15)
+    # mine.compute_score(x, y)
+    #
+    # print("Without noise:")
+    # print("MIC", mine.mic())
+    # print()
+    #
+    # np.random.seed(0)
+    # y += np.random.uniform(-1, 1, x.shape[0])  # add some noise
+    # mine.compute_score(x, y)
+    #
+    #
+    # def MIC_matirx(dataframe, mine):
+    #
+    #     datamnist = np.array(dataframe)
+    #     n = len(datamnist[0, :])
+    #     result = np.zeros([n, n])
+    #
+    #     for i in range(n):
+    #         for j in range(n):
+    #             mine.compute_score(datamnist[:, i], datamnist[:, j])
+    #             result[i, j] = mine.mic()
+    #             result[j, i] = mine.mic()
+    #     RT = result
+    #     return RT
+    #
+    #
+    # mine = MINE(alpha=0.6, c=5)
+    # data_wine_mic = MIC_matirx(
+    #     np.array([[1, 2, 3, 4, 5, 1, 5, 2, 1, 4], [2, 3, 4, 1, 2, 1, 3, 1, 6, 1], [6, 4, 5, 3, 4, 1, 4, 1, 6, 2]]).T,
+    #     mine)
+
